@@ -2,12 +2,13 @@
 
 ## Faire les docstrings : """...""" ##
 
-## Import des modules essentiels ##
-
+## Import des modules & packages essentiels ##
+## Packages extérieurs
 import giacpy
-import donnees
-import erreurs as er
-import random as r
+import random
+
+## Modules internes
+from DAHU.donnees import pi
 
 # Utilisation de Giac pour gestion des variables et des expressions et autres pitits trucs #
 
@@ -116,7 +117,7 @@ class Matrice :
                 matrice.append(t)
             self.Matrice = matrice
         else :
-            er.Error_1()
+            pass
     
     def __repr__(self) : #Representation lors de l'utilisation de print()
         l = self.nbl
@@ -152,7 +153,7 @@ class Matrice :
                         mat[i][j] = self[i][j] + autre[i][j]
                 return mat
             else :
-                er.Error_ma_6()
+                pass
         else :
             pass
 
@@ -162,9 +163,9 @@ class Matrice :
                 matreturn = self + autre
                 return matreturn
             else :
-                er.Error_ma_6()
+                pass
         else :
-            er.Error_ma_2(ty="Matrice")
+            pass
     
     def __sub__(self,autre) : #Soustraction de deux matrices
         if isinstance(autre,Matrice) :
@@ -175,9 +176,9 @@ class Matrice :
                         mat[i][j] = self[i][j] - autre[i][j]
                 return mat
             else :
-                er.Error_ma_6()
+                pass
         else :
-            er.Error_ma_2(ty="Matrice")
+            pass
     
     def __isub__(self,autre) : #Utilisation de l'operateur -= !
         return self - autre
@@ -201,7 +202,7 @@ class Matrice :
                     mat[i][j] = self[i][j]*float(autre)
             return mat
         else :
-            er.Error_6()
+            pass
 
     def __rmul__(autre,self) : #Commutativite de la multiplication par un scalaire (faire les filtres)
         if isinstance(autre,int) :
@@ -416,9 +417,8 @@ class Complexe :
             self.th = 0
         elif self.a == 0 and self.b != 0 :
             self.r = self.b
-            self.th = donnees.pi/2
+            self.th = (pi)/2
         return (self.r, self.th)
-        pass
 
 class Fonction(Expression) :
     def __init__(self,nom,expr,var) :
@@ -451,9 +451,22 @@ class Fonction(Expression) :
 
     ## Définition des différents types de fonctions
 
-class Polynôme :
-    def __init__(self):
-        pass
+class Polynôme() :
+    def __init__(self,coef,var):
+        self.coef = coef
+        p = ""
+        for i in range(len(self.coef)) :
+            a = float(self.coef[i])
+            p = p + "(" + str(a) + ")*" + var + "^(" + str(len(self.coef)-i)+ ")"
+            if i != len(self.coef) :
+                p += "+"
+        b = [var]
+        print(p)
+        self.expr = Expression(p,b)
+        self.expr = self.expr.simp()
+    
+    def __repr__(self):
+        return self.expr.sexpr
 
 class Ensemble :
 
@@ -469,7 +482,7 @@ class Intervalle(Ensemble) :
 ## Définitions de quelques opérations ##
 
 def prodvec(vec1,vec2) : #Produit vectoriel de deux vecteurs de R3 (faire les filtres) !
-    if er.Error_ma_1(Vecteur,vec1,vec2) :
+    if True :
         if len(vec1) == len(vec2) == 3 :
             vec = Vecteur(3)
             vec[0] = vec1[1]*vec2[2] - vec1[2]*vec2[1]
@@ -485,7 +498,7 @@ def randomatrice(lignes,colonnes,xmin=-15,xmax=15) : #Generation d'une matrice a
     mat = Matrice(lignes,colonnes)
     for i in range(lignes) :
         for j in range(colonnes) :
-            mat[i][j] = r.randint(xmin,xmax)
+            mat[i][j] = random.randint(xmin,xmax)
     return mat
 
 def matrice123(lignes,colonnes) : #Generation d'une matrice suivant la suite des entiers naturels !
@@ -524,7 +537,7 @@ def matriceel(element) : #Generation d'une matrice à partir d'une liste de list
                 mat[i][j] = element[i][j]
         return mat
     else :
-        er.Error_ma_5()
+        pass
 
 def mat_creuse_1(ligne, colonne, valeur,n) : #Matrice creuse contenant 1 valeur à la position (ligne,colonne)
     mat = Matrice(n,n)
@@ -559,6 +572,9 @@ def mel_transvection(ligne_1,ligne_2,valeur,n) : #Matrice elementaire de transve
 def taylor(expr,var,pt,ordre) :
     expr.sucderiv(var,ordre)
 
+def approx_fourrier():
+    pass
+
 
 ## Fonctions Arithmétiques ##
 
