@@ -25,17 +25,17 @@ import maths as ma
 # b = a.pivots()
 # print (b)
 
-h = ma.Expression("2*x**3-6*x*y+2*y**3-3*x-3*y",var=["x","y"])
-print(h)
-a = h.deriv("x").simp()
-b = h.deriv("y").simp()
-print(a)
-print(b)
-print(h)
+# h = ma.Expression("2*x**3-6*x*y+2*y**3-3*x-3*y",var=["x","y"])
+# print(h)
+# a = h.deriv("x").simp()
+# b = h.deriv("y").simp()
+# print(a)
+# print(b)
+# print(h)
 
 # f = ma.Expression("e^(x^2-y)*(5-2*x+y)",var=["x","y"])
 # a = f.lim("x","+infinity")
 # print(a)
 
-a = ma.matrice123(4,4)
-print(a.eigenval())
\ No newline at end of file
+a = ma.Polynôme([1,2,3],"t")
+print(a)
\ No newline at end of file
